@@ -41,7 +41,8 @@ class ImsClient(AbstractClient):
         - 支持用户自定义选择图片风险库，打击自定义识别类型的违规图片（目前仅支持黑名单配置）；
         - 支持在审核图片内容时同时关联账号或设备信息，可识别违规风险账号或设备。
         ### 接口调用说明：
-        - 图片尺寸支持：**长或者宽 >50分辨率**和**长或者宽<40000分辨率**,并且**图片长宽比<90:1；**
+        - 图片文件大小支持：**文件<100M**
+        - 图片尺寸支持：**长和宽 需>50分辨率且<40000分辨率，并且图片长宽比<90:1；**
         - 图片文件分辨率支持：建议**分辨率大于256x256**，否则可能会影响识别效果；
         - 图片文件支持格式：PNG、JPG、JPEG、BMP、GIF、WEBP格式；
         - 图片文件链接支持的传输协议：HTTP、HTTPS；
@@ -84,8 +85,8 @@ class ImsClient(AbstractClient):
         - 支持在审核图片内容时同时关联账号或设备信息，可识别违规风险账号或设备。
 
         ### 接口调用说明：
-        - 图片文件大小支持：**文件 < 5M**
-        - 图片默认尺寸支持：**长或者宽 >50分辨率**和**长或者宽<10000分辨率**
+        - 图片文件大小支持：**文件 < 30M**
+        - 图片默认尺寸支持：**长和宽 需>50分辨率且<10000分辨率，并且图片长宽比<90:1；**
         - 图片文件分辨率支持：建议**分辨率大于256x256**，否则可能会影响识别效果；
         - 图片文件支持格式：PNG、JPG、JPEG、BMP、GIF、WEBP格式；
         - 图片文件链接支持的传输协议：HTTP、HTTPS；
